@@ -1,5 +1,5 @@
 package JSON::Karabiner ;
-$JSON::Karabiner::VERSION = '0.015';
+$JSON::Karabiner::VERSION = '0.016';
 use strict;
 use warnings;
 use JSON;
@@ -37,6 +37,7 @@ sub new {
     }
   }
   bless $self, $class;
+  { no warnings 'once'; $main::has_delayed_action = ''; }
   return $self;
 }
 
@@ -65,8 +66,6 @@ sub write_file {
         push @main::saved_manips, @{$manip};
       }
     }
-    use Data::Dumper qw(Dumper);
-    print Dumper $s->{_karabiner}->{rules}[0];
 
     @{$s->{_karabiner}->{rules}[0]{manipulators}} = @main::saved_manips;
   }
@@ -577,7 +576,7 @@ modules|https://www.cpan.org/modules/INSTALL.html> for more information.
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 Development Status
 
