@@ -1,5 +1,5 @@
 package JSON::Karabiner::Manipulator::Actions::To_delayed_if_canceled ;
-$JSON::Karabiner::Manipulator::Actions::To_delayed_if_canceled::VERSION = '0.015';
+$JSON::Karabiner::Manipulator::Actions::To_delayed_if_canceled::VERSION = '0.016';
 use strict;
 use warnings;
 use JSON;
@@ -9,16 +9,28 @@ use parent 'JSON::Karabiner::Manipulator::Actions::To';
 sub new {
   my $class = shift;
   my ($type, $value) = @_;
-  my $obj = $class->SUPER::new('to_delayed_action', $value);
+  my $has_delayed_action;
+  { no warnings 'once';
+    $has_delayed_action = $main::has_delayed_action;
+  }
+  my $obj;
+  if ($main::has_delayed_action) {
+    use Data::Dumper qw(Dumper);
+    print Dumper 'kajskfj';
+    $obj = $main::has_delayed_action;
+  } else {
+    $obj = $class->SUPER::new('to_delayed_action', $value);
+    $obj->{data} = {};
+  }
   $obj->{delayed_type} = 'canceled';
   if ($value) {
     $obj->{data} = $value,
   } else {
-    $obj->{data} = {};
     $obj->{data}{to_if_canceled} = [];
 
 #    $obj->{data}{to_delayed_action}{to_if_invoked} = [];
   }
+  $main::has_delayed_action = $obj;
   return $obj;
 }
 
@@ -36,7 +48,7 @@ JSON::Karabiner::Manipulator::Actions::To_delayed_if_canceled - to_delayed_if_ca
 
 =head1 VERSION
 
-version 0.015
+version 0.016
 
 =head1 AUTHOR
 
